function [pm] = AdaptMutation(Distance,pm,pmutmx,pmutmn,AdaptRate)
%
% AdaptMutation adapts the mutation probability based on the distance
% measure of the current generation and an adaptation rate parameter
%
% [pm] = AdaptMutation(Distance,pm,pmutmx,pmutmn,AdaptRate)
%
% INPUTS:
% Distance - Measure of clustering in the present generation
% pm - Probability of mutation
% pmutmx - Maximum mutation probability 
% pmutmin - Minimum mutation probability
% AdaptRate - Rate of adaptiation
%
% OUTPUTS:
% pm - Adapted mutation probability


DistLow = 0.05; %level of clustering necessary for adaptation to occur
DistHigh = 0.25; %level of diversity necessary for adaptation to occur

if Distance <= DistLow
    pm = min(pm*AdaptRate,pmutmx); %increase pm
elseif Distance >= DistHigh
    pm = max(pm/AdaptRate,pmutmn); %decrease pm
end
