function [SP] = AdaptSelectPressure(Distance,SP,SPmax,SPmin,AdaptRate) 

% AdaptSelectPressure adapts the selection pressure (fitness differential)
% based on the distance measure of the current generation and an adaptation 
% rate parameter
%
% [SP] = AdaptSelectPressure(Distance,SP,SPmax,SPmin,AdaptRate) 
%
% INPUTS:
% Distance - Measure of clustering in the present generation
% SP - Selection pressure (fitness differential)
% SPmax - Maximum selection pressure 
% pmutmin - Minimum selection pressure
% AdaptRate - Rate of adaptiation
%
% OUTPUTS:
% SP - Adapted selection pressure

DistLow = 0.05; %level of clustering necessary for adaptation to occur
DistHigh = 0.25; %level of diversity necessary for adaptation to occur

if Distance <= DistLow
    SP = max((SP-(SPmax+SPmin-SP)*AdaptRate),SPmin); %decrease selection pressure
elseif Distance >= DistHigh
    SP = min((SP+(SPmax+SPmin-SP)/AdaptRate),SPmax); %increase selection pressure
end