function [InitialPop] = CreateUniform(A,b,Aeq,beq,LB,UB,nonlcon,options)
%
% CreateUniform generates a uniformly distributed random population of parameters
% within the specified upper and lower parameter bounds.
%
% [InitialPop] = CreateUniform(A,b,Aeq,beq,LB,UB,nonlcon,options)
%
% INPUTS:
% A,b - Matrix A and vector b specifying linear inequality constraints (Ax<b)
% Aeq, beq - Matrix Aeq and vector beq specifying linear equality constraints
% (Ax=b)
% LB - Lower parameter bound vector
% UB - Upper parameter bound vector
% nonlcon - function handle for a non linear constraint
% options - BELUGA options structure
%
% OUTPUTS:
% InitialPop - Random population of parameters subject to bounds and
% constraints.


for n = 1:options.PopulationSize
    
    feasible = 0;
    tic;
    while feasible == 0
        parset = LB + (UB-LB).*rand(1,length(UB));
        feasible = CheckCons(parset,A,b,Aeq,beq,LB,UB,nonlcon,options.Precision);
        t=toc;
        if t>60
            error('Error: No feasible population found. Problem possibly overconstrained.');
        end
    end
    InitialPop(n,:) = parset;
end
