function [parameterpopulation] = DecodeDecimal(genome,LB,UB,Precision)

% DecodeDecimal decodes decimally encoded population of chromosomes
% 
% [parameterpopulation] = DecodeDecimal(genome,LB,UB,Precision)
%
% INPUTS:
% genome - decimally encoded population of chromosomes
% LB - Lower parameter bound row vector 
% UB - Upper parameter bound row vector
% Precision - Vector of number of significant digits in each scaled
% parameter
%
% OUTPUTS
% parameterpopulation - decoded population

parameterpopulation = zeros(size(genome,1),length(LB)); %preallocate for speed
%decode each parameter from the genome
for i = 1:size(genome,1)
    for j = 1:length(LB)
        parameterpopulation(i,j)=(1/10^Precision(j))*...
            sum(...
            10.^(0:Precision(j)-1).*genome(...
            i,sum((j>1)*Precision(1:(1*(j<=1)+(j>1)*(j-1))))+(1:Precision(j))...
            )...
            );
    end
end

parameterpopulation = ...
    repmat(LB,size(parameterpopulation,1),1)+...
    parameterpopulation.*repmat(UB-LB,size(parameterpopulation,1),1);