function [genome] = EncodeDecimal(parameterpopulation,LB,UB,Precision)

% EncodeDecimal encodes the supplied parameterpopulation into a decimal coded
% genome i.e a matrix of chromosomes. Input parameters are mapped to [0 1]
% where 0 corresponds to the lower bound and 1 corresponds to the upper
% bound. Mapped parameters are decimally encoded to a specified number of 
% significant digits in the vector Precision.
%
% [genome] = EncodeDecimal(parameterpopulation,LB,UB,Precision)
%
% INPUTS:
% parameterpopulation - decoded population
% LB - Lower parameter bound row vector 
% UB - Upper parameter bound row vector
% Precision - Vector of number of significant digits in each scaled
% parameter
%
% OUTPUTS:
% genome - decimally encoded population of chromosomes


% Map parameters to [0 1], corresponding to [LB UB]
parameterpopulation = ...
    (parameterpopulation-repmat(LB,size(parameterpopulation,1),1))./...
    repmat(UB-LB,size(parameterpopulation,1),1);

% encode each individual of the parameter population i.e each parameterset
% into chromosomes
genome = zeros(size(parameterpopulation,1),sum(Precision));%preallocate for speed
for i = 1:size(parameterpopulation,1)
    for j = 1:length(LB)
        genome(i,...
            sum((j>1)*Precision(1:(1*(j<=1)+(j>1)*(j-1))))+(1:Precision(j))) = ...
            mod(floor((10.^(Precision(j)+1-(1:Precision(j)))).*...
            parameterpopulation(i,j)),10);
    end
end