function [pmcrit] = FindCriticalMutRate(S,C)

% FindCriticalMutRate caculates the critical mutation rate for a chromosome
% of length S
%
% [pmcrit] = FindCriticalMutRate(S,C)
%
% INPUTS
% S - chromosome length
% C - population size
%
% OUTPUTS
% pmcrit - Critical mutation probability
%
%

A = 10;     %Decimal alphabet
N = S-1;    %Equilibrium correct letter count

myfun = @ (p,N,A,S,C) (((1-(1-p).^N).*(1-p./A)).^C - 1 + (1-p./A).^C) ;
p0 = 0:0.01:1;
opts = optimset('TolFun',1e-6,'TolX',1e-6,'Display','off');

for i=1:length(p0)
    popt(i) = fsolve(@(p) myfun(p,N,A,S,C),p0(i),opts); %#ok<AGROW>
end

pmcrit = max(popt(popt>0 & popt <1));
if isempty(pmcrit) || pmcrit < 1e-2
    pmcrit = 0.25;
end


