function [Parent] = Roulette(ScaledFitness,SelectionPressure)
%
% Roulette returns the index of a selected parent from an array of 
% Scaled Fitness Ranks 
%
% [Parent] = Roulette(ScaledFitness,SelectionPressure)
% 
% INPUTS:
% ScaledFitness - Vector containing normalized fitness ranks of the current
% generation
% SelectionPressure - Fitness differential scalar to increase the probability of
% selection of fitter individuals
%
% OUTPUTS:
% Parent - Index of chosen individual (integer scalar)

np = length(ScaledFitness);

% Normalized Ranking scheme with a Selection Pressure (Eq 3.8 from A User's
% Guide to PIKAIA)

Sprime_r = ((SelectionPressure+1)*(np+1) - ...
    2*np*ScaledFitness*SelectionPressure)/(np*(np+1));

Parent=find(cumsum(Sprime_r)>=rand,1);