function [chromosome] = UniformMutation(pm,MutationCreep,Precision,chromosome)
%
% UniformMutation mutates a given decimally encoded chromosome
%
% [chromosome] = UniformMutation(pm,MutationCreep,Precision,chromosome)
% 
% INPUTS:
% pm - mutation probability (scalar)
% MutationCreep - Option string ('on or 'off') for creep mutation
% Precision - Vector containing encoding precisions for parameters
% chromosome - chromosome to be mutated
%
% Note: This mutation operator can be generalized to any integer base
% representation by replacing 10 with the integer base

if strcmp(MutationCreep,'on') %use creep mutation
    flip = rand;
else
    flip = 0; %no creep mutation
end

if flip < 0.5 %one-point mutation
    mutgenes = (rand(1,length(chromosome))<pm).*... %mutation probability test
        (floor(10*rand(1,length(chromosome)))); %mutation
    chromosome(mutgenes~=0) = mutgenes(mutgenes~=0);% assign mutated genes
else %creep mutation (flip >= 0.5)
    for i=1:length(Precision)
        for j=1:Precision(i)
            if rand < pm %mutation probability test
                inc =round(rand)*2-1; %Increment/Decrement
                ist = sum(Precision(1:(i==1)+(i>1)*(i-1)))+1; % left substring boundary
                x = chromosome(ist:ist-1+Precision(i)); % extract substring from chromosome
                mutposition = j; %specify mutation position
                mutx=sum(x.*10.^(length(x)-1 : -1 : 0))+...%represent x as an n digit integer
                    inc*10.^(length(x)-mutposition); % creep mutation = addition/subtraction 10^(n-j)
                if ~(mutx>=10^(length(x)) || mutx<=0) % test for creep carryover beyond substring boundaries
                    mutxgenes=floor(mod(mutx,10.^(length(x) : -1 : 1))./...
                        10.^(length(x)-1 : -1 : 0)); %recover mutated substring
                    chromosome(ist:ist-1+Precision(i)) = mutxgenes; %place mutated substring in chromosome
                end
            end
        end
    end
end
                    
                    
                            
            