function [offspring1,offspring2] = XoverHybrid(parent1,parent2,XoverRate)
%
% XoverHybrid       Performs crossover operation on two parent chromosomes
%                   to produce two offspring chromosomes. Uniform one-point
%                   or two-point crossover is used with 0.5 probability for
%                   each operation. This function is equivalent to CROSS in
%                   PIKAIA 1.2          
%
% [offspring1,offspring2] = XoverHybrid(parent1,parentP2,XoverRate)
% INPUTS:
% parent1 - parent chromosome 1, integer vector
% parent2 - parent chromosome 2, integer vector
% XoverRate - crossover probability, scalar
%  
% OUTPUTS:
% offspring1 - generated offspring 1, integer vector
% offspring2 - generated offspring 2, integer vector



% Warning: Explicit Material
if XoverRate > rand % Crossover if crossover rate is greater than 
                    %a uniformly distributed random number in [0 1]
    % Initialize flip with a uniformly distributed random number in [0 1]
    flip = rand; 
    if flip < 0.5 % Single point crossover if flip lies in [0 0.5)
        nXover = length(parent1)-1; %Number of possible crossover points 
        % Select crossover point in the parent chromosomes:
        % Divide [0 1] into nXover bins and pick one bin based on the bin where
        % a uniformly distributed random number falls
        bins = 0:1/nXover:1;
        Xpoint = rand;               
        % Swap genes located left of the crossover point to produce
        % offspring
        offspring1 = (parent2.*(bins<Xpoint)+parent1.*(bins>Xpoint));
        offspring2 = (parent1.*(bins<Xpoint)+parent2.*(bins>Xpoint));      
    elseif flip>= 0.5 % Two point crossover if flip lies in [0 0.5)
        nXover = length(parent1)-1; %Number of possible crossover points 
        bins = 0:1/nXover:1;
        Xpoint = sort(rand(1,2),2,'ascend');
        % Swap genes located left of the lower crossover point and to the 
        % right of the hogher crossover point to produce offspring 
        offspring1 = (parent2.*(bins<Xpoint(1) | bins>Xpoint(2))+...
            parent1.*(bins>Xpoint(1) & bins<Xpoint(2)));
        offspring2 = (parent1.*(bins<Xpoint(1) | bins>Xpoint(2))+...
            parent2.*(bins>Xpoint(1) & bins<Xpoint(2)));
    end
else % if Xover rate is lower than the generated random number
    offspring1 = parent1;
    offspring2 = parent2;
end




